==> otools-0.1.0.tar.gz: otools-0.1.0/README.md <==
# OTools

[![Documentation Status](https://readthedocs.org/projects/otools/badge/?version=latest)](https://otools.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/gabriel-milan/otools.svg?branch=master)](https://travis-ci.org/gabriel-milan/otools)
[![PyPI Version](https://img.shields.io/pypi/v/otools)](https://pypi.org/project/otools/)
[![Python Versions](https://img.shields.io/pypi/pyversions/otools)](https://github.com/gabriel-milan/otools)
[![Vulnerabilities](https://img.shields.io/snyk/vulnerabilities/github/gabriel-milan/otools)](https://snyk.io/test/github/gabriel-milan/otools)
[![License](https://img.shields.io/github/license/gabriel-milan/otools)](https://github.com/gabriel-milan/otools/blob/master/LICENSE)

OTools stands for Online Tools, which is a Python/Cython framework for developing multithread online systems in a simple way.

This framework is the evolution of [Akuanduba](https://github.com/gabriel-milan/Akuanduba), a very similar framework I've developed.
Although Akuanduba seemed OK to me, I realized it wasn't really user-friendly. OTools was developed to get as simple as possible
and yet powerful.

## Installation

Just install it by using pip!

```
pip3 install otools
```

## Getting started

I wouldn't recommend going straight to the [examples](https://github.com/gabriel-milan/otools/tree/master/examples) or trying to write code of your own,
but it's up to you!

My recommendation is:

* Read the [OTools 101](https://otools.readthedocs.io/en/latest/#otools-101) at the docs (or just read the [full documentation](https://otools.readthedocs.io/en/latest))
* Start by running the [simplest example](https://github.com/gabriel-milan/otools/tree/master/examples/simple_example)
* (Optional) Check out few [other examples](https://github.com/gabriel-milan/otools/tree/master/examples)
* Write code of your own
* Submit issues [here](https://github.com/gabriel-milan/otools/issues).

## Future releases

* Implement CLI (?)

==> otools-0.2.2.tar.gz: otools-0.2.2/README.md <==
# OTools

[![Documentation Status](https://readthedocs.org/projects/otools/badge/?version=latest)](https://otools.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/gabriel-milan/otools.svg?branch=master)](https://travis-ci.org/gabriel-milan/otools)
[![PyPI version](https://badge.fury.io/py/otools.svg)](https://pypi.org/project/otools/)
[![Vulnerabilities](https://snyk.io/test/github/gabriel-milan/otools/badge.svg)](https://snyk.io/test/github/gabriel-milan/otools)
[![License](https://img.shields.io/github/license/gabriel-milan/otools)](https://github.com/gabriel-milan/otools/blob/master/LICENSE)

OTools stands for Online Tools, which is a Python/Cython framework for developing multithread online systems in a simple way.

This framework is the evolution of [Akuanduba](https://github.com/gabriel-milan/Akuanduba), a very similar framework I've developed.
Although Akuanduba seemed OK to me, I realized it wasn't really user-friendly. OTools was developed to get as simple as possible
and yet powerful.

## Installation

Just install it by using pip!

```
pip3 install otools
```

## Getting started

I wouldn't recommend going straight to the [examples](https://github.com/gabriel-milan/otools/tree/master/examples) or trying to write code of your own,
but it's up to you!

My recommendation is:

* Read the [OTools 101](https://otools.readthedocs.io/en/latest/#otools-101) at the docs (or just read the [full documentation](https://otools.readthedocs.io/en/latest))
* Start by running the [simplest example](https://github.com/gabriel-milan/otools/tree/master/examples/simple_example)
* (Optional) Check out few [other examples](https://github.com/gabriel-milan/otools/tree/master/examples)
* Write code of your own
* Submit issues [here](https://github.com/gabriel-milan/otools/issues).

## Future releases

* Implement CLI (?)
